@@ -13,10 +13,7 @@ use noodles_core::{region::Interval, Region};
 use noodles_csi::BinningIndex;
 use noodles_tabix as tabix;
 
-const LINE_FEED: char = '\n';
-const CARRIAGE_RETURN: char = '\r';
-
-const HEADER_PREFIX: u8 = b'#';
+use super::Header;
 
 /// A VCF reader.
 ///
@@ -30,20 +27,20 @@ const HEADER_PREFIX: u8 = b'#';
 /// # Examples
 ///
 /// ```no_run
-/// # use std::{fs::File, io::{self, BufReader}};
+/// # use std::{fs::File, io::BufReader};
 /// use noodles_vcf as vcf;
 ///
 /// let mut reader = File::open("sample.vcf")
 ///     .map(BufReader::new)
 ///     .map(vcf::Reader::new)?;
 ///
-/// reader.read_header()?;
+/// let header = reader.read_header()?.parse()?;
 ///
-/// for result in reader.records() {
+/// for result in reader.records(&header) {
 ///     let record = result?;
 ///     println!("{:?}", record);
 /// }
-/// # Ok::<(), io::Error>(())
+/// # Ok::<_, Box<dyn std::error::Error>>(())
 /// ```
 #[derive(Debug)]
 pub struct Reader<R> {
@@ -192,7 +189,6 @@ where
     /// # Examples
     ///
     /// ```no_run
-    /// # use std::io;
     /// use noodles_vcf as vcf;
     ///
     /// let data = b"##fileformat=VCFv4.3
@@ -201,15 +197,15 @@ where
     /// ";
     ///
     /// let mut reader = vcf::Reader::new(&data[..]);
-    /// let header = reader.read_header()?;
+    /// let header = reader.read_header()?.parse()?;
     ///
-    /// let mut records = reader.records();
+    /// let mut records = reader.records(&header);
     /// assert!(records.next().is_some());
     /// assert!(records.next().is_none());
-    /// # Ok::<(), io::Error>(())
+    /// # Ok::<_, Box<dyn std::error::Error>>(())
     /// ```
-    pub fn records(&mut self) -> Records<'_, R> {
-        Records::new(self)
+    pub fn records<'r, 'h>(&'r mut self, header: &'h Header) -> Records<'r, 'h, R> {
+        Records::new(self, header)
     }
 }
 
@@ -270,7 +266,7 @@ where
     /// # Examples
     ///
     /// ```no_run
-    /// # use std::{fs::File, io};
+    /// # use std::fs::File;
     /// use noodles_bgzf as bgzf;;
     /// use noodles_core::Region;
     /// use noodles_tabix as tabix;
@@ -280,21 +276,36 @@ where
     ///     .map(bgzf::Reader::new)
     ///     .map(vcf::Reader::new)?;
     ///
+    /// let header = reader.read_header()?.parse()?;
+    ///
     /// let index = tabix::read("sample.vcf.gz.tbi")?;
     /// let region = Region::mapped("sq0", 8..=13);
-    /// let query = reader.query(&index, &region)?;
+    /// let query = reader.query(&header, &index, &region)?;
     ///
     /// for result in query {
     ///     let record = result?;
     ///     println!("{:?}", record);
     /// }
-    /// Ok::<(), io::Error>(())
+    /// Ok::<_, Box<dyn std::error::Error>>(())
     /// ```
-    pub fn query(&mut self, index: &tabix::Index, region: &Region) -> io::Result<Query<'_, R>> {
+    pub fn query<'r, 'h>(
+        &'r mut self,
+        header: &'h Header,
+        index: &tabix::Index,
+        region: &Region,
+    ) -> io::Result<Query<'r, 'h, R>> {
         let (reference_sequence_id, reference_sequence_name, interval) =
             resolve_region(index, region)?;
+
         let chunks = index.query(reference_sequence_id, interval)?;
-        Ok(Query::new(self, chunks, reference_sequence_name, interval))
+
+        Ok(Query::new(
+            self,
+            chunks,
+            reference_sequence_name,
+            interval,
+            header,
+        ))
     }
 }
 
@@ -302,6 +313,9 @@ fn read_header<R>(reader: &mut R) -> io::Result<String>
 where
     R: BufRead,
 {
+    const HEADER_PREFIX: u8 = b'#';
+    const LINE_FEED: u8 = b'\n';
+
     let mut header_buf = Vec::new();
     let mut is_eol = false;
 
@@ -312,7 +326,7 @@ where
             break;
         }
 
-        let (read_eol, len) = if let Some(i) = memchr(LINE_FEED as u8, buf) {
+        let (read_eol, len) = if let Some(i) = memchr(LINE_FEED, buf) {
             header_buf.extend(&buf[..=i]);
             (true, i + 1)
         } else {
@@ -335,6 +349,9 @@ fn read_line<R>(reader: &mut R, buf: &mut String) -> io::Result<usize>
 where
     R: BufRead,
 {
+    const LINE_FEED: char = '\n';
+    const CARRIAGE_RETURN: char = '\r';
+
     match reader.read_line(buf) {
         Ok(0) => Ok(0),
         Ok(n) => {
