@@ -28,7 +28,7 @@ pub use self::genotypes::{genotype, Genotype};
 
 #[deprecated(
     since = "0.11.0",
-    note = "Use `noodles_vcf::record::genotypes::Format` instead."
+    note = "Use `noodles_vcf::record::genotypes::Keys` instead."
 )]
 pub use self::genotypes::Keys as Format;
 
@@ -248,6 +248,36 @@ impl Record {
         &self.reference_bases
     }
 
+    /// Returns a mutable reference to the reference bases of the record.
+    ///
+    /// This is a required field and guaranteed to be nonempty.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_vcf::{
+    ///     self as vcf,
+    ///     record::{reference_bases::Base, Position, ReferenceBases},
+    /// };
+    ///
+    /// let mut record = vcf::Record::builder()
+    ///     .set_chromosome("sq0".parse()?)
+    ///     .set_position(Position::try_from(1)?)
+    ///     .set_reference_bases("A".parse()?)
+    ///     .build()?;
+    ///
+    /// *record.reference_bases_mut() = "T".parse()?;
+    ///
+    /// assert_eq!(
+    ///     record.reference_bases(),
+    ///     &ReferenceBases::try_from(vec![Base::T])?,
+    /// );
+    /// # Ok::<(), Box<dyn std::error::Error>>(())
+    /// ```
+    pub fn reference_bases_mut(&mut self) -> &mut ReferenceBases {
+        &mut self.reference_bases
+    }
+
     /// Returns the alternate bases of the record.
     ///
     /// # Examples
@@ -275,6 +305,34 @@ impl Record {
         &self.alternate_bases
     }
 
+    /// Returns a mutable reference to the alternate bases of the record.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_vcf::{
+    ///     self as vcf,
+    ///     record::{alternate_bases::Allele, reference_bases::Base, AlternateBases, Position},
+    /// };
+    ///
+    /// let mut record = vcf::Record::builder()
+    ///     .set_chromosome("sq0".parse()?)
+    ///     .set_position(Position::try_from(1)?)
+    ///     .set_reference_bases("A".parse()?)
+    ///     .build()?;
+    ///
+    /// *record.alternate_bases_mut() = "C".parse()?;
+    ///
+    /// assert_eq!(
+    ///     record.alternate_bases(),
+    ///     &AlternateBases::from(vec![Allele::Bases(vec![Base::C])]),
+    /// );
+    /// # Ok::<(), Box<dyn std::error::Error>>(())
+    /// ```
+    pub fn alternate_bases_mut(&mut self) -> &mut AlternateBases {
+        &mut self.alternate_bases
+    }
+
     /// Returns the quality score of the record.
     ///
     /// The quality score is a [Phred quality score].
@@ -498,6 +556,43 @@ impl Record {
     pub fn genotypes(&self) -> &Genotypes {
         &self.genotypes
     }
+
+    /// Returns a mutable reference to the genotypes of the record.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_vcf::{
+    ///     self as vcf,
+    ///     record::{
+    ///         genotypes::{genotype::{field::{Key, Value}, Field}, Genotype, Genotypes},
+    ///         Position,
+    ///     },
+    /// };
+    ///
+    /// let mut record = vcf::Record::builder()
+    ///     .set_chromosome("sq0".parse()?)
+    ///     .set_position(Position::try_from(1)?)
+    ///     .set_reference_bases("A".parse()?)
+    ///     .build()?;
+    ///
+    /// let keys = "GT:GQ".parse()?;
+    /// let genotypes = Genotypes::new(
+    ///     keys,
+    ///     vec![Genotype::try_from(vec![
+    ///         Field::new(Key::Genotype, Some(Value::String(String::from("0|0")))),
+    ///         Field::new(Key::ConditionalGenotypeQuality, Some(Value::Integer(13))),
+    ///     ])?],
+    /// );
+    ///
+    /// *record.genotypes_mut() = genotypes.clone();
+    ///
+    /// assert_eq!(record.genotypes(), &genotypes);
+    /// # Ok::<(), Box<dyn std::error::Error>>(())
+    /// ```
+    pub fn genotypes_mut(&mut self) -> &mut Genotypes {
+        &mut self.genotypes
+    }
 }
 
 /// An error returned when the end position is invalid.
