@@ -4,7 +4,11 @@ pub mod base;
 
 pub use self::base::Base;
 
-use std::{error, fmt, ops::Deref, str::FromStr};
+use std::{
+    error, fmt,
+    ops::{Deref, DerefMut},
+    str::FromStr,
+};
 
 use super::MISSING_FIELD;
 
@@ -20,6 +24,12 @@ impl Deref for ReferenceBases {
     }
 }
 
+impl DerefMut for ReferenceBases {
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+
 impl fmt::Display for ReferenceBases {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         for base in self.iter() {
